@@ -173,7 +173,11 @@ static void bg_album_track_id(bg_tree_t *tree FFUNUSED, int *id FFUNUSED)
 #endif // ]
 
 static bg_tree_vmt_t bg_album_vmt={
+#if defined (PBU_MESSAGE_AV_LOG) // [
+  .id="album",
+#else // ] [
   .id=FFL("album"),
+#endif // ]
   .type=BG_TREE_TYPE_ALBUM,
   .destroy=bg_album_destroy,
   .accept=bg_album_accept,
