@@ -767,16 +767,22 @@ static void bg_tag(void *data, bg_bits_t *bits, const char *key,
   char ovalue[128];
   double gain;
 
+  ENTER(__func__);
+
   if (!key) {
     _DMESSAGE("missing key");
+    LEAVE();
     return;
   }
+PRINTF(__FILE__,__LINE__,"key:%s\n",key);
 
   if (STRNCASECMP(param->tag.pfx,key,len)) {
     if (!ivalue) {
       _DMESSAGE("missing value");
+      LEAVE();
       return;
     }
+PRINTF(__FILE__,__LINE__,"ivalue:%s\n",ivalue);
 
     // plain copy.
     av_dict_set(om,key,ivalue,BG_MUXER_FLAGS);
@@ -848,6 +854,7 @@ static void bg_tag(void *data, bg_bits_t *bits, const char *key,
     }
   }
   else if (!STRCASECMP(key+len,"ALBUM_PEAK")) {
+PUTS(__FILE__,__LINE__,"ALBUM_PEAK\n");
     if (BG_FLAGS_MODE_TAGS_ALBUM&param->flags.mode) {
       if ((BG_FLAGS_MODE_APPLY&param->flags.mode)||!parent
           ||!(BG_FLAGS_AGG_PEAK&param->flags.aggregate)) {
@@ -868,6 +875,7 @@ static void bg_tag(void *data, bg_bits_t *bits, const char *key,
   else {
     // suppress.
   }
+  LEAVE();
 }
 
 #if defined (FF_STREAM_METADATA) // [
