@@ -150,6 +150,9 @@ int bg_param_create(bg_param_t *param)
   param->flags.extension=0;
   param->flags.mode=0;
   param->flags.aggregate=BG_FLAGS_AGG_INTEGRATED;
+#if defined (HAVE_TRUE_PEAK_DEFAULT) // [
+  param->flags.aggregate|=BG_FLAGS_AGG_TRUEPEAK;
+#endif // ]
   param->flags.norm=BG_FLAGS_NORM_EBU;
 #if defined (BG_PARAM_DUMP) // [
   param->dump=0;
@@ -340,6 +343,9 @@ int bg_param_loop(bg_param_t *param, ffchar_t *const *argv)
 {
   int err=-1;
 
+  ENTER(__func__);
+  PRINTF(__FILE__,__LINE__,"%d\n",param->flags.aggregate&BG_FLAGS_AGG_TRUEPEAK);
+
 #if ! defined (BG_PARAM_LOOP_INNER) // [
   /////////////////////////////////////////////////////////////////////////////
   if (bg_root_create(&param->root,param)<0) {
@@ -397,7 +403,8 @@ e_prefix:
   param->root.vmt->destroy(&param->root);
 e_root:
 #endif // ]
-  return err;
+  //return err;
+  return RETURN_INT(__FILE__,__LINE__,err);
 }
 
 ///////////////////////////////////////////////////////////////////////////////
