@@ -47,10 +47,15 @@ int64_t bg_parse_time(const ffchar_t *s)
       ts*=10ll;
       ts+=*s-FFL('0');
     }
+#if 0 // [
     else {
       _DMESSAGEV("unexpected character '\\x%x' in timestamp",*s);
       goto exit;
     }
+#else // ] [
+    else
+      break;
+#endif // ]
   }
 
   if (FFL('.'==*s)) {
