@@ -35,7 +35,9 @@
 #include <libavformat/avformat.h>
 #include <libswresample/swresample.h>
 #include <libswscale/swscale.h>
+#if defined (HAVE_LIBPOSTPROC) // [
 #include <libpostproc/postprocess.h>
+#endif // ]
 #include <libavfilter/avfilter.h>
 
 #if defined (__cplusplus) // [
@@ -43,9 +45,22 @@ extern "C" {
 #endif // ]
 
 ///////////////////////////////////////////////////////////////////////////////
+#define FF_TOBIAS_BUG_FIX
 #define FF_MUXEER_CONTINUE_ON_INVALIDDATA
+//#define FF_MUXEER_FIFO
+#if defined (FF_MUXEER_FIFO) // [
+#define FF_FIFO
+#endif // ]
 //#define FF_BITMASK_BASED_CHANNEL_LAYOUT
-#define FF_SAMPLE_FMTS_DEPRECATED
+#if defined (HAVE_WORKINPROGRESS) // [
+#define FF_FILTER_REDESIGNED
+#define FF_INOUT_REDESIGNED
+#else // ] [
+#define FF_SAMPLE_FMTS_DEPRECATED_QUICK_FIX
+#if ! defined (FF_SAMPLE_FMTS_DEPRECATED_QUICK_FIX) // [
+#define FF_SAMPLE_FMTS_DEPRECATED_FIX
+#endif // ]
+#endif // ]
 //libav: Switch to new channel layout API: https://gitlab.freedesktop.org/gstreamer/gstreamer/-/issues/2833
 #define FF_HOLZHAMMER
 #if defined (FF_HOLZHAMMER) // [
@@ -65,7 +80,6 @@ extern "C" {
 #endif // ]
 #endif // ]
 
-//#define FF_FIFO
 //#define FF_WARN_CHANNEL_OVERFLOW_AV_LOG
 //#define FF_WARN_CHANNEL_OVERFLOW_DISABLE
 #define FF_PROGRESS_STDERR
@@ -715,12 +729,14 @@ int ff_filter_send_frame(ff_filter_t *filter, AVFrame *frame);
 int ff_filter_receive_frame(ff_filter_t *filter, AVFrame *frame);
 
 ///////////////////////////////////////////////////////////////////////////////
+#if defined (FF_FIFO) // [
 // fifo not used. just for reference.
 struct ff_fifo {
   AVCodecParameters ocodecpar;
   int flush;
   AVAudioFifo *fifo;
 };
+#endif // ]
 
 int ff_fifo_create(ff_fifo_t *fifo, const AVCodecParameters *ocodecpar);
 void ff_fifo_destroy(ff_fifo_t *fifo);
@@ -748,6 +764,10 @@ struct ff_muxer {
 
   struct {
     int64_t ts;
+#if defined (FF_MUXEER_FIFO) // [
+    //AVAudioFifo *fifo;
+    ff_fifo_t fifo;
+#endif // ]
   } audio;
 };
 
