@@ -38,6 +38,7 @@ FF_DISABLE_DEPRECATION_WARNINGS // [
 #define FF_ANALYZER_OCODECPAR_PTR
 #define FF_ANALYZER_STATS_CREATE
 //#define FF_ANALYZER_STATS_DESTROY
+
 int ff_analyzer_create(ff_analyzer_t *a, ff_inout_t *in)
 {
   ff_input_callback_t *cb=in->cb.in;
@@ -58,6 +59,7 @@ int ff_analyzer_create(ff_analyzer_t *a, ff_inout_t *in)
 #else // ] [
   AVCodecParameters *icodecpar,ocodecpar;
 #endif // err
+  ENTER(__func__);
 
   /////////////////////////////////////////////////////////////////////////////
   if (in->ai<0) {
@@ -206,6 +208,8 @@ int ff_analyzer_create(ff_analyzer_t *a, ff_inout_t *in)
   }
 
   /////////////////////////////////////////////////////////////////////////////
+  PRINTF(__FILE__,__LINE__,"upsample:%p\n",cb?cb->upsample:NULL);
+  PRINTF(__FILE__,__LINE__,"upsample:%d\n",upsample);
   if (1<upsample) {
 #if defined (FF_ANALYZER_OCODECPAR_PTR) // [
     /*
@@ -252,7 +256,8 @@ int ff_analyzer_create(ff_analyzer_t *a, ff_inout_t *in)
     a->upsampler.ctx=NULL;
 
   /////////////////////////////////////////////////////////////////////////////
-  return 0;
+  //return 0;
+  return RETURN_INT(__FILE__,__LINE__,0);
 //cleanup:
   if (a->upsampler.ctx)
     resampler_destroy(&a->upsampler);
@@ -276,7 +281,8 @@ e_normalizer_ocodecpar_copy:
 e_normalizer_ocodecpar:
 #endif // ]
 e_args:
-  return -1;
+  //return -1;
+  return RETURN_INT(__FILE__,__LINE__,-1);
 }
 
 void ff_analyzer_destroy(ff_analyzer_t *a, int destroy_stats)
@@ -309,9 +315,17 @@ static int ff_analyzer_process_frame(ff_analyzer_t *a, AVFrame *frame)
 {
   ff_input_callback_t *cb=a->in->cb.in;
   void *data=a->in->cb.data;
+#if 0 && defined (FF_TOBIAS_BUG_FIX) // [
+  int (*fun_upsample)(const void *data)=cb?cb->upsample:NULL;
+  int flag_upsample=fun_upsample(data);
+#endif // ]
   int (*add)(void *, int, AVFrame *)=cb?cb->stats.add:NULL;
   int err;
 
+//#warning add
+PRINTF(__FILE__,__LINE__,"a->normalizer.ctx: %p\n",a->normalizer.ctx);
+PRINTF(__FILE__,__LINE__,"add: %p\n",add);
+PRINTF(__FILE__,__LINE__,"a->upsampler.ctx: %p\n",a->upsampler.ctx);
   if (a->normalizer.ctx) {
     // normalize.
     err=resampler_apply(&a->normalizer,frame);
@@ -321,9 +335,14 @@ static int ff_analyzer_process_frame(ff_analyzer_t *a, AVFrame *frame)
       goto exit;
     }
 
-    if (add) {
+#if 0 && defined (FF_TOBIAS_BUG_FIX) // [
+PRINTF(__FILE__,__LINE__,"fun_upsample: %p\n",fun_upsample);
+PRINTF(__FILE__,__LINE__,"flag_upsample: %d\n",flag_upsample);
+    if (flag_upsample) {
       // add to normalized non-upsample statistics.
-      err=add(data,0,a->normalizer.frame);
+ENTER_LINE(__FILE__,__LINE__);
+      err=add(data,flag_upsample,a->normalizer.frame);
+LEAVE();
 
       if (err<0) {
         _DMESSAGEV("adding normalized statistics: %s (%d)",
@@ -333,7 +352,9 @@ static int ff_analyzer_process_frame(ff_analyzer_t *a, AVFrame *frame)
 
       if (!frame) {
         // we need to flush normalized non-upsample statistics.
-        err=add(data,0,NULL);
+ENTER_LINE(__FILE__,__LINE__);
+        err=add(data,flag_upsample,NULL);
+LEAVE();
 
         if (err<0) {
           _DMESSAGEV("flushing normalized statistics: %s (%d)",
@@ -342,10 +363,39 @@ static int ff_analyzer_process_frame(ff_analyzer_t *a, AVFrame *frame)
         }
       }
     }
+#else // ] [
+    if (add) {
+      // add to normalized non-upsample statistics.
+ENTER_LINE(__FILE__,__LINE__);
+      err=add(data,0,a->normalizer.frame);
+LEAVE();
+
+      if (err<0) {
+        _DMESSAGEV("adding normalized statistics: %s (%d)",
+            av_err2str(err),err);
+        goto exit;
+      }
+
+      if (!frame) {
+        // we need to flush normalized non-upsample statistics.
+ENTER_LINE(__FILE__,__LINE__);
+        err=add(data,0,NULL);
+LEAVE();
+
+        if (err<0) {
+          _DMESSAGEV("flushing normalized statistics: %s (%d)",
+              av_err2str(err),err);
+          goto exit;
+        }
+      }
+    }
+#endif // ]
   }
   else if (add) {
     // add non-normalized non-upsample statistics.
+ENTER_LINE(__FILE__,__LINE__);
     err=add(data,0,frame);
+LEAVE();
 
     if (err<0) {
       _DMESSAGEV("adding statistics: %s (%d)",av_err2str(err),err);
@@ -364,7 +414,9 @@ static int ff_analyzer_process_frame(ff_analyzer_t *a, AVFrame *frame)
 
     if (add) {
       // add to upsample statistics.
+ENTER_LINE(__FILE__,__LINE__);
       err=add(data,1,a->upsampler.frame);
+LEAVE();
 
       if (err<0) {
         _DMESSAGEV("adding upsampled statistics: %s (%d)",
@@ -375,7 +427,9 @@ static int ff_analyzer_process_frame(ff_analyzer_t *a, AVFrame *frame)
 
       if (!frame) {
         // we need to flush upsample statistics.
+ENTER_LINE(__FILE__,__LINE__);
         err=add(data,1,NULL);
+LEAVE();
 
         if (err<0) {
           _DMESSAGEV("flushing upsampled statistics: %s (%d)",
