@@ -108,6 +108,8 @@ int ff_input_create(ff_inout_t *in, ff_input_callback_t *cb, void *data,
   const AVStream *istream;
   int err;
 
+  ENTER(__func__);
+
   /////////////////////////////////////////////////////////////////////////////
   in->cb.in=cb;
   in->cb.data=data;
@@ -286,7 +288,9 @@ int ff_input_create(ff_inout_t *in, ff_input_callback_t *cb, void *data,
   }
 
   /////////////////////////////////////////////////////////////////////////////
-  return 0;
+  //return 0;
+//PUTS(__FILE__,__LINE__,"NO CALLBACK\n");
+  return RETURN_INT(__FILE__,__LINE__,0);
 //cleanup:
 e_seek:
   if (in->audio.ctx)
@@ -299,7 +303,8 @@ e_csv:
 e_image:
   avformat_close_input(&in->fmt.ctx);
 e_context:
-  return -1;
+  //return -1;
+  return RETURN_INT(__FILE__,__LINE__,-1);
 }
 
 void ff_input_destroy(ff_inout_t *in)
@@ -323,6 +328,8 @@ int ff_input_open_analyzer(ff_inout_t *in)
   int64_t seek=cb&&cb->interval.begin?cb->interval.begin(data):-1ll;
   int err;
 
+  ENTER(__func__);
+
   /////////////////////////////////////////////////////////////////////////////
   in->cb.in=cb;
   in->cb.data=data;
@@ -393,7 +400,8 @@ int ff_input_open_analyzer(ff_inout_t *in)
   }
 
   /////////////////////////////////////////////////////////////////////////////
-  return 0;
+  //return 0;
+  return RETURN_INT(__FILE__,__LINE__,0);
 //cleanup:
 e_seek:
   if (in->audio.ctx)
@@ -403,7 +411,8 @@ e_find:
 e_csv:
   avformat_close_input(&in->fmt.ctx);
 e_context:
-  return -1;
+  //return -1;
+  return RETURN_INT(__FILE__,__LINE__,-1);
 }
 
 #if defined (FF_FLAC_HACK) // [
