@@ -34,6 +34,10 @@
 FF_DISABLE_DEPRECATION_WARNINGS // [
 #endif // }
 
+#if defined (FF_TOBIAS_BUG_FIX) // [
+#define FF_RESAMLPER_CONFIG_FRAME
+#endif // ]
+ 
 ///////////////////////////////////////////////////////////////////////////////
 int ff_resampler_create(ff_resampler_t *res,
     const AVCodecParameters *ocodecpar,
@@ -42,9 +46,11 @@ int ff_resampler_create(ff_resampler_t *res,
   int err=-1;
 #if defined (FF_BITMASK_BASED_CHANNEL_LAYOUT) // [
   int64_t ochannel_layout=ocodecpar->channel_layout;
-
+#else // ] [
+  AVChannelLayout och_layout FFUNUSED=ocodecpar->ch_layout;
 #endif // ]
 
+  ENTER(__func__);
 #if defined (FF_RESAMPLER_RATE) // [
   /////////////////////////////////////////////////////////////////////////////
   res->irate=icodecpar->sample_rate;
@@ -56,7 +62,7 @@ int ff_resampler_create(ff_resampler_t *res,
 
   /////////////////////////////////////////////////////////////////////////////
 #if defined (FF_BITMASK_BASED_CHANNEL_LAYOUT) // [
-  if (!ochannel_layout||!icodecpar->channel_layout) {
+  if (!och_layout||!icodecpar->ch_layout) {
 #if defined (_WIN32) // [
     fwprintf(stderr,L"invalid channel layout: output=%I64d input=%I64d",
         ochannel_layout,icodecpar->channel_layout);
@@ -66,6 +72,11 @@ int ff_resampler_create(ff_resampler_t *res,
 #endif // ]
     goto e_channel_layout;
   }
+#else // ] [
+  if (!av_channel_layout_check(&och_layout)||!av_channel_layout_check(&icodecpar->ch_layout)) {
+      DMESSAGE("missing channellayout for input or output");
+    goto e_channel_layout;
+  }
 #endif // ]
 
   /////////////////////////////////////////////////////////////////////////////
@@ -89,13 +100,16 @@ int ff_resampler_create(ff_resampler_t *res,
     goto e_context;
   }
 #else // ] [
+PUTS(__FILE__,__LINE__,"\n");
   res->ctx=swr_alloc();
+PRINTF(__FILE__,__LINE__,"res->ctx:%p\n",res->ctx);
 
   if (!res->ctx) {
     _DMESSAGE("allocating context");
     goto e_context;
   }
 
+#if 0 // [
   av_opt_set_chlayout(res->ctx, "in_chlayout",    &icodecpar->ch_layout, 0);
   av_opt_set_int(res->ctx, "in_sample_rate",       icodecpar->sample_rate, 0);
   av_opt_set_sample_fmt(res->ctx, "in_sample_fmt", icodecpar->format, 0);
@@ -103,6 +117,28 @@ int ff_resampler_create(ff_resampler_t *res,
   av_opt_set_chlayout(res->ctx, "out_chlayout",    &ocodecpar->ch_layout, 0);
   av_opt_set_int(res->ctx, "out_sample_rate",       ocodecpar->sample_rate, 0);
   av_opt_set_sample_fmt(res->ctx, "out_sample_fmt", ocodecpar->format, 0);
+#else // ] [
+  err=av_opt_set_chlayout(res->ctx, "in_chlayout",&icodecpar->ch_layout, 0);
+
+  if (err<0) {
+    _DMESSAGEV("setting option 'in_chlayout': %s (%d)",av_err2str(err),err);
+    goto e_opt_set;
+  }
+
+  err=av_opt_set_int(res->ctx, "in_sample_rate",icodecpar->sample_rate, 0);
+
+  if (err<0) {
+    _DMESSAGEV("setting option 'in_sample_rate': %s (%d)",av_err2str(err),err);
+    goto e_opt_set;
+  }
+
+  err=av_opt_set_sample_fmt(res->ctx, "in_sample_fmt",icodecpar->format, 0);
+
+  if (err<0) {
+    _DMESSAGEV("setting option 'in_sample_fmt': %s (%d)",av_err2str(err),err);
+    goto e_opt_set;
+  }
+#endif // ]
 #endif // ]
 
   /////////////////////////////////////////////////////////////////////////////
@@ -123,17 +159,18 @@ int ff_resampler_create(ff_resampler_t *res,
   res->frame->sample_rate=ocodecpar->sample_rate;
 
   /////////////////////////////////////////////////////////////////////////////
-  err=0;
+  //err=0;
+  return RETURN_INT(__FILE__,__LINE__,0);
 //cleanup:
+e_opt_set:
   av_frame_free(&res->frame);
 e_frame:
   swr_close(res->ctx);
   swr_free(&res->ctx);
 e_context:
-#if defined (FF_BITMASK_BASED_CHANNEL_LAYOUT) // [
 e_channel_layout:
-#endif // ]
-  return err;
+  //return err;
+  return RETURN_INT(__FILE__,__LINE__,err);
 }
 
 void resampler_destroy(ff_resampler_t *res)
@@ -227,6 +264,16 @@ int resampler_apply(ff_resampler_t *res, AVFrame *frame)
   }
 #endif // ]
 
+#if defined (FF_RESAMLPER_CONFIG_FRAME) // [
+  /////////////////////////////////////////////////////////////////////////////
+  err=swr_config_frame(res->ctx,res->frame,frame);
+
+  if (err<0) {
+    _DMESSAGEV("configuring frame: %s (%d)",av_err2str(err),err);
+    goto econfig;
+  }
+#endif // ]
+
   /////////////////////////////////////////////////////////////////////////////
   err=swr_convert_frame(res->ctx,res->frame,frame);
 
@@ -238,6 +285,9 @@ int resampler_apply(ff_resampler_t *res, AVFrame *frame)
   /////////////////////////////////////////////////////////////////////////////
   return 0;
 econvert:
+#if defined (FF_RESAMLPER_CONFIG_FRAME) // [
+econfig:
+#endif // ]
 #if defined (FF_RESAMPLER_RATE) // [
 #if defined (FF_RESAMPLER_GET_BUFFER) // [
 e_buffer:
