@@ -33,10 +33,46 @@ extern "C" {
 #endif
 
 ///////////////////////////////////////////////////////////////////////////////
+#if defined (HAVE_PBU_TRACE) // [
 //#define PBU_DEBUG
+#define PBU_TRACE
+#endif // ]
 #define PBU_MESSAGE_AV_LOG
 #define PBU_LIST_RING
 
+///////////////////////////////////////////////////////////////////////////////
+#if defined (PBU_TRACE) // [
+void pbu_trc_depth(const char *path, int line);
+void pbu_trc_enter(const char *id);
+FILE *pbu_trc_line(const char *path, int line);
+void pbu_trc_enter_line(const char *path, int line);
+void pbu_trc_leave(void);
+int pbu_trc_return_int(const char *path, int line, int ret);
+
+#define ENTER(id) \
+	pbu_trc_enter(id)
+#define DEPTH(path,line) \
+	pbu_trc_depth(path,line)
+#define ENTER_LINE(path,line) \
+	pbu_trc_enter_line(path,line)
+#define PRINTF(path,line,format,__VARGS__) \
+	fprintf(pbu_trc_line(path,line),format,__VARGS__)
+#define PUTS(path,line,s) \
+	fprintf(pbu_trc_line(path,line),"%s",s)
+#define LEAVE() \
+	pbu_trc_leave()
+#define RETURN_INT(path,line,ret) \
+	pbu_trc_return_int(path,line,ret)
+#else // ] [
+#define ENTER(id)
+#define DEPTH(path,line)
+#define ENTER_LINE(path,line)
+#define LEAVE()
+#define RETURN_INT(path,line,ret) (ret)
+#define PRINTF(path,line,format,__VARGS__)
+#define PUTS(path,line,s)
+#endif // ]
+
 ///////////////////////////////////////////////////////////////////////////////
 #if defined (_WIN32) // {
 #define PBU_WIDEN2(x) L ## x
@@ -381,6 +417,8 @@ void pbu_vwritelna(FILE *f, const char *path, int line, const char *func,
 int pbu_same_file(const char *path1, const char *path2);
 char *pbu_extend_path(const char *dirname, const char *basename);
 const char *pbu_ext(const char *path);
+// we don't understand why the following prototype isn't visible
+// in "pbu_trace.c".
 const char *pbu_basename(const char *path);
 void pbu_mkdir(char *path);
 
